---
comments: true
icon: material/bookshelf
---

# 教程和文档

<div markdown>

!!! success inline "3.0.x"

    * 最新版本: `3.0.1`
    * 版本类型: 稳定版本
    * 当前状态: 🟢 <font color="limegreen">持续更新</font>

    [<small>:fontawesome-solid-paper-plane:</small> 打开链接](https://xiaokang2022.github.io/maliang-docs/3.0/){ .md-button target="_black" }

!!! info "支持"

    - [X] 提交文档错误报告
    - [ ] 多语言支持
    - [X] 官方教程
    - [X] 参考文档
    - [X] 实战教学

</div>

<div markdown>

!!! failure inline "2.6.x"

    * 最新版本: `2.6.21`
    * 版本类型: 不支持版本
    * 当前状态: 🔴 <font color="red">停止更新</font>

    [<small>:fontawesome-solid-paper-plane:</small> 打开链接](https://xiaokang2022.github.io/maliang-docs/2.6/){ .md-button target="_black" }

!!! info "支持"

    - [ ] 提交文档错误报告
    - [ ] 多语言支持
    - [X] 官方教程
    - [X] 参考文档
    - [ ] 实战教学

</div>
